@@ -27,7 +27,7 @@ use UI::Dialog::Backend;
 BEGIN {
   use vars qw( $VERSION @ISA );
   @ISA = qw( UI::Dialog::Backend );
-  $VERSION = '1.16';
+  $VERSION = '1.17';
 }
 
 #::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
@@ -326,7 +326,8 @@ sub checklist {
   my $fmt = $self->prepare_format($args);
   $fmt = $self->append_format_base($args,$fmt);
   $fmt = $self->append_format($fmt,'--separate-output');
-  if (defined $args->{radiolist} && $args->{radiolist}) {
+  $args->{radiolist} ||= 0;
+  if ($args->{radiolist}) {
     $fmt = $self->append_format($fmt,'--radiolist');
   } else {
     $fmt = $self->append_format($fmt,'--checklist');
@@ -337,7 +338,7 @@ sub checklist {
       text => $self->make_kvt($args,$args->{'text'}),
     );
 
-  if (exists $args->{radiolist} && $args->{radiolist} == 1) {
+  if ($args->{radiolist}) {
     my ($rv,$selected) = $self->command_string($command);
     return($rv == 0 ? $selected : 0);
   }
