@@ -29,7 +29,7 @@ use String::ShellQuote;
 BEGIN {
   use vars qw( $VERSION @ISA );
   @ISA = qw( UI::Dialog::Backend );
-  $VERSION = '1.16';
+  $VERSION = '1.17';
 }
 
 #::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
@@ -359,6 +359,8 @@ sub list {
   my $fmt = $self->prepare_format($args);
   $fmt = $self->append_format_base($args,$fmt);
   $fmt = $self->append_format($fmt,'--list');
+  $args->{'checklist'} ||= 0;
+  $args->{'radiolist'} ||= 0;
   if ($args->{'checklist'}) {
     $fmt = $self->append_format($fmt,'--checklist');
   }
