@@ -23,7 +23,7 @@ use constant { TRUE => 1, FALSE => 0 };
 
 BEGIN {
     use vars qw($VERSION);
-    $VERSION = '1.16';
+    $VERSION = '1.17';
 }
 
 use UI::Dialog;
@@ -50,7 +50,7 @@ sub new {
           PATH => (defined $args{PATH}) ? $args{PATH} : undef,
           beepbefore => (defined $args{beepbefore}) ? $args{beepbefore} : undef,
           beepafter => (defined $args{beepafter}) ? $args{beepafter} : undef,
-          'trust-input' => ($args{'trust-input'}==1) ? 1 : 0,
+          'trust-input' => (defined $args{'trust-input'} && $args{'trust-input'} == 1) ? 1 : 0,
          );
     }
     unless (exists $args{menu}) {
